rhythmmakertools.InciseSpecifier
================================

.. abjad-lineage:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier

.. autoclass:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.body_ratio
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.fill_with_notes
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.incise_divisions
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.incise_output
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.prefix_lengths
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.prefix_talea
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.reverse
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.rotate
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.suffix_lengths
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.suffix_talea
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.talea_denominator
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.__eq__
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.__format__
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.__hash__
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.__ne__
      ~abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.__repr__

Bases
-----

- :py:class:`abctools.AbjadValueObject <abjad.tools.abctools.AbjadValueObject.AbjadValueObject>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.body_ratio
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.fill_with_notes
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.incise_divisions
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.incise_output
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.prefix_lengths
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.prefix_talea
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.suffix_lengths
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.suffix_talea
   :noindex:

.. autoattribute:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.talea_denominator
   :noindex:

Methods
-------

.. automethod:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.reverse
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.rotate
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.__eq__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.__format__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.__hash__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.__ne__
   :noindex:

.. automethod:: abjad.tools.rhythmmakertools.InciseSpecifier.InciseSpecifier.__repr__
   :noindex:
